==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AMultiNewExpr__24ArrayDescriptor__5fCast.h <==
// class soot.jimple.parser.node.AMultiNewExpr$ArrayDescriptor_Cast

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 84d1b931f1ffd52f soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_
#define _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_AMultiNewExpr$object;
struct _jc_soot_jimple_parser_node_AMultiNewExpr__241$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object;

typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$_init$c86fd01123f782f5(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr$object *);
extern void _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$_init$a268cea193a615d1(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__241$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method_info$cast$7f4f4803dccc49ec;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs {
	struct _jc_soot_jimple_parser_node_AMultiNewExpr$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs {
    _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object {
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AMultiNewExpr__24ArrayDescriptor__5fCast.h <==
// class soot.jimple.parser.node.AMultiNewExpr$ArrayDescriptor_Cast

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 84d1b931f1ffd52f soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_
#define _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_AMultiNewExpr$object;
struct _jc_soot_jimple_parser_node_AMultiNewExpr__241$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object;

typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$_init$c86fd01123f782f5(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$_init$a268cea193a615d1(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr$object *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$method_info$cast$7f4f4803dccc49ec;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vmethods	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs {
	struct _jc_soot_jimple_parser_node_AMultiNewExpr$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs {
    _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_refs	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$sub_nonrefs	soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$object {
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$vtype _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_AMultiNewExpr__24ArrayDescriptor__5fCast_H_ */
